@@ -40,7 +40,7 @@ sub enqueue {
   my $doc = {
     args    => $args,
     created => bson_time,
-    delayed => bson_time($options->{delayed} ? $options->{delayed} : 1),
+    delayed => bson_time($options->{delayed} ? $options->{delayed} * 1000 : 1),
     priority => $options->{priority} // 0,
     state    => 'inactive',
     task     => $task
